@@ -2,6 +2,12 @@ import requests
 
 from cloudtipsadp.connect.clients import Connect
 from cloudtipsadp.connect.repository import Repository
+from cloudtipsadp import constants as cnt
+
+try:
+    from simplejson import JSONDecodeError
+except ImportError:
+    from json import JSONDecodeError
 
 
 class AccumulationRepository(Repository):
@@ -15,8 +21,11 @@ class AccumulationRepository(Repository):
 
     def get(self, obj_id):
         """Накопления получателя."""
-        url = self(self.base_path, obj_id, 'summary')
-        return self.req.get(url, headers=self.session.get_headers()).json()
+        try:
+            url = self(self.base_path, obj_id, 'summary')
+            return self.req.get(url, headers=self.session.get_headers()).json()
+        except JSONDecodeError:
+            print(cnt.CTA, cnt.JSON_ERR_OBJECT)
 
     def list(self):
         raise NotImplementedError()
@@ -29,6 +38,9 @@ class AccumulationRepository(Repository):
 
     def payout_receiver(self, user_id):
         """Выплата накопления получателю."""
-        url = self(self.base_path, 'payout', user_id)
-        return self.req.post(url,
-                             headers=self.session.get_headers()).json()
+        try:
+            url = self(self.base_path, 'payout', user_id)
+            return self.req.post(url,
+                                 headers=self.session.get_headers()).json()
+        except JSONDecodeError:
+            print(cnt.CTA, cnt.JSON_ERR_OBJECT)
