@@ -1,14 +1,8 @@
 import os
 from dataclasses import dataclass
 
-BASE_URL_default = 'https://identity-sandbox.cloudtips.ru'
-BASE_URL_API_default = 'https://api-sandbox.cloudtips.ru'
-
-print(os.environ.get('CTA_BASE_URL'))
-print(os.environ.get('CTA_BASE_URL_API'))
-
-BASE_URL = os.environ.get('CTA_BASE_URL', BASE_URL_default)
-BASE_URL_API = os.environ.get('CTA_BASE_URL_API', BASE_URL_API_default)
+BASE_URL = os.environ.get('CTA_BASE_URL')
+BASE_URL_API = os.environ.get('CTA_BASE_URL_API')
 
 CTA_CLIENT_ID = os.environ.get('CTA_CLIENT_ID', 'Partner')
 CTA_USER_NAME = os.environ.get('CTA_USER_NAME')
